$warning-color: #E57200;


QWidget {
  border-radius: 0;
  border-width: 0;
  color: $primary-text-color;
  font: 300 normal 12px "Ubuntu";
  margin: 0;
  padding: 0;
  selection-background-color: $primary-selection-color;
  selection-color: $secondary-text-color;
}

QWidget:focus {
  outline: None;
  text-decoration: underline;
}

QFileDialog QLineEdit,
QFileDialog QTextArea,
QFileDialog QComboBox,
QFileDialog QComboBox:item,
QFileDialog QComboBox:item:checked,
QFileDialog QMenu,
QFileDialog QToolTip
{
  background: #FFFFFF;
}

QFileDialog QComboBox:item{
  max-height: 24px;
}

QTextEdit {
  /* This affects all textboxes, search boxes and form boxes. Must be adjusted
   * to match the height of the buttons.
   */
  background-color: $primary-background-color;
  border: 1px solid $primary-background-color-alt-4;
  border-radius: 4px;
  font: 300 normal 12px "Ubuntu";
  outline: none;
  padding: 4px 6px;
}

QTextEdit:focus,
QTextEdit:hover {
  border: 1px solid $primary-selection-color;
}

QLineEdit,
QTextArea {
  /* This affects all textboxes, search boxes and form boxes. Must be adjusted
   * to match the height of the buttons.
   */
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-4;
  border-radius: 4px;
  font: 300 normal 12px "Ubuntu";
  max-height: 16px;
  min-height: 16px;
  padding: 4px 6px;
}

QLineEdit:focus,
QLineEdit:hover,
QTextArea:focus,
QTextArea:hover {
  border: 1px solid $primary-selection-color;
}


QScrollArea {
  background: $primary-background-color-alt-2;
}

/* Vertical Scroll */
QScrollBar:add-page:vertical, QScrollBar:sub-page:vertical {
  background: none;
}

QScrollBar:vertical {
  background: $primary-background-color-alt-4;
  margin: 20px 0 20px 0;
  width: 16px;
}

QScrollBar:handle:vertical {
  background-color: $primary-background-color-alt-6;
  margin: 1px 0;
  min-height: 8px;
  max-height: 200px;
}

QScrollBar:up-arrow:vertical {
  image: url('$STYLED_ICONS_PATH/sort-asc.svg');
  border: 0 solid $primary-background-color-alt-7;
  width: 16px;
  height: 16px;
}

QScrollBar:sub-line:vertical {
  background-color: $primary-background-color-alt-6;
  height: 20px;
  subcontrol-position: top;
  subcontrol-origin: margin;
}

QScrollBar:down-arrow:vertical {
  image: url('$STYLED_ICONS_PATH/sort-desc.svg');
  border: 0 solid $primary-background-color-alt-7;
  width: 16px;
  height: 16px;
}

QScrollBar:add-line:vertical {
  background-color: $primary-background-color-alt-6;
  height: 20px;
  subcontrol-position: bottom;
  subcontrol-origin: margin;
}

/* Horizontal Scroll */
QScrollBar:add-page:horizontal, QScrollBar::sub-page:horizontal {
  background: none;
}

QScrollBar:horizontal {
  background: $primary-background-color-alt-4;
  margin: 0 20px 0 20px;
  height: 16px;
}

QScrollBar:handle:horizontal {
  background-color: $primary-background-color-alt-6;
  margin: 0 1px;
  min-width: 8px;
  max-width: 200px;
}

QScrollBar:left-arrow:horizontal {
  image: url('$STYLED_ICONS_PATH/arrow-left.svg');
  border: 0 solid $primary-background-color-alt-7;
  height: 16px;
  width: 16px;
}

QScrollBar:right-arrow:horizontal {
  image: url('$STYLED_ICONS_PATH/arrow-right.svg');
  border: 0 solid $primary-background-color-alt-6;
  height: 16px;
  width: 16px;
}

QScrollBar:sub-line:horizontal {
  background-color: $primary-background-color-alt-6;
  width: 20px;
  subcontrol-position: left;
  subcontrol-origin: margin;
}

QScrollBar:add-line:horizontal {
  background-color: $primary-background-color-alt-6;
  width: 20px;
  subcontrol-position: right;
  subcontrol-origin: margin;
}

QScrollBar:handle:hover {
  background-color: $primary-background-color-alt-5;
}

QScrollBar:sub-line:hover {
  background-color: $primary-background-color-alt-5;
}

QMenuBar {
  background: $primary-background-color;
}

QMenuBar:item {
  background: transparent;
  border-radius: 0;
  padding: 4px 8px;
  spacing: 3px;
}

QMenuBar:item:selected {
  /* when selected using mouse or keyboard */
  background: $primary-selection-color;
  color: $secondary-text-color;
}

QMenuBar:item:pressed {
  background: $primary-background-color-alt-2;
  color: $primary-text-color;
}

QMenu {
  background-color: $primary-background-color;
  border: 1px solid $primary-background-color-alt-4;
  menu-scrollable: 1;
  /* Reserve space for selection border */
}

QMenu:separator {
  width: 1px;
  height: 1px;
}

QMenu:indicator:checked {
  image: url("$IMAGE_PATH/icons/check-active.svg");
}

QMenu:item {
  border: 1px solid transparent;
  /* Reserve space for selection border */
  padding: 8px 24px;
}

QMenu:item:selected {
  background: $primary-background-color-alt-2;
  color: $primary-selection-color;
}

QMenu:item:disabled {
  background: transparent;
  color: $primary-text-color-alt-2;
}

QCheckBox,
QRadioButton {
  outline: none; /* Remove the focus rectangle in ubuntu and osx */
  padding-right: 6px;
}

QCheckBox:indicator,
QRadioButton:indicator {
  height: 16px;
  width: 16px;
}

QCheckBox:indicator:disabled:unchecked,
QAbstractItemView:indicator:disabled:unchecked {
  image: url("$IMAGE_PATH/icons/check-box-disabled.svg");
}

QRadioButton:indicator:disabled:unchecked {
  image: url("$IMAGE_PATH/icons/radio-button-disabled.svg");
}

QCheckBox:indicator:disabled:checked,
QAbstractItemView:indicator:disabled:checked {
  image: url("$IMAGE_PATH/icons/check-box-checked-disabled.svg");
}

QRadioButton:indicator:disabled:checked {
  image: url("$IMAGE_PATH/icons/radio-button-checked-disabled.svg");
}

QCheckBox:indicator:unchecked,
QAbstractItemView:indicator:unchecked {
  image: url("$STYLED_ICONS_PATH/check-box-blank.svg");
}

QRadioButton:indicator:unchecked {
  image: url("$STYLED_ICONS_PATH/radio-button-blank.svg");
}

QCheckBox:indicator:unchecked:hover,
QCheckBox:indicator:unchecked:focus,
QAbstractItemView:indicator:unchecked:hover,
QAbstractItemView:indicator:unchecked:focus {
  image: url("$IMAGE_PATH/icons/check-box-active.svg");
}

QRadioButton:indicator:unchecked:hover,
QRadioButton:indicator:unchecked:focus {
  image: url("$IMAGE_PATH/icons/radio-button-active.svg");
}

QCheckBox:indicator:unchecked:pressed,
QAbstractItemView:indicator:unchecked:pressed {
  image: url("$STYLED_ICONS_PATH/check-box-blank.svg");
}

QRadioButton:indicator:unchecked:pressed {
  image: url("$STYLED_ICONS_PATH/radio-button-blank.svg");
}

QCheckBox:indicator:checked,
QAbstractItemView:indicator:checked {
  image: url("$STYLED_ICONS_PATH/check-box-checked.svg");
}

QRadioButton:indicator:checked {
  image: url("$STYLED_ICONS_PATH/radio-button-checked.svg");
}

QCheckBox:indicator:checked:focus,
QCheckBox:indicator:checked:checked:hover,
QAbstractItemView:indicator:checked:checked:focus,
QAbstractItemView:indicator:checked:checked:hover {
  image: url("$IMAGE_PATH/icons/check-box-checked-active.svg");
}

QRadioButton:indicator:checked:focus,
QRadioButton:indicator:checked:checked:hover {
  image: url("$IMAGE_PATH/icons/radio-button-checked-active.svg");
}

QComboBox {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-4;
  border-radius: 4px;
  padding-right: 16px; /* Equal to the down arrow size */
  /* Styles every list item within the dropdown list */
  /* "Trigger" */
  /* "Closed" state */
  /* This is the actual dropdown box */
}

QComboBox:focus,
QComboBox:hover {
  border: 1px solid $primary-selection-color;
}

QComboBox:indicator {
  image: none; /* This will appear in all lines */
}

QComboBox::down-arrow {
  image: url("$STYLED_ICONS_PATH/sort-desc.svg");
  max-width: 16px;
  min-width: 16px;
}

QComboBox::drop-down {
  border-left-width: 1px;
  border-left-color: darkgray;
  border-left-style: solid;
  subcontrol-origin: padding;
  subcontrol-position: top right;
  width: 15px;
}

QComboBox:on::drop-down {
  /* Height can be changed here */
  /*border-radius: 0;*/
  height: 24px;
  min-height: 24px;
  min-width: 8em;
  padding-top: 0;
  padding-left: 24px;
}

QComboBox:on::drop-down#package-version {
  /* Height can be changed here */
  min-width: 1.5em;
}

QComboBox:on::drop-down#r-type {
  /* Height can be changed here */
  min-width: 1.5em;
}

QComboBox:on::drop-down#environment-selection {
  /* Height can be changed here */
  min-width: 18em;
}

QComboBox:item {
  border: 1px solid transparent;
  /* The presently selected item */
  /* Hover states for all list items */
}

QComboBox:item:checked {
  color: $primary-selection-color;
  background-image: url("$STYLED_ICONS_PATH/check.svg");
}

QComboBox:item:selected {
  color: $primary-selection-color;
  background: $secondary-text-color;
}

QComboBox QAbstractItemView {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-4;
}

QTabWidget:pane {
  border-top: 0 solid $primary-background-color;
}

QTabWidget:tab-bar {
  left: 12px;
  /* move to the right by 5px */
}

QTabBar:tab {
  background: $primary-background-color-alt-1;
  border: 0 solid $primary-background-color-alt-4;
  /*border-top: 2px solid $primary-background-color-alt-2;*/
  color: $primary-selection-color;
  min-width: 6em;
  min-height: 20px;
  padding: 8px 10px;
}

QTabBar:tab:hover {
  background: $primary-background-color-alt-3;
  border-top: 2px solid $primary-background-color-alt-2;
  color: $primary-selection-color;
}

QTabBar:tab:selected {
  background: $primary-background-color-alt-3;
  color: $primary-selection-color;
  border-top: 2px solid $primary-selection-color;
}

QToolTip {
  color: $primary-text-color;
  font: 300 normal 11px "Ubuntu";
  border: 1px solid $primary-background-color-alt-4;
  background: $primary-background-color;
  padding: 8px;
  opacity: 250;
}

QHeaderView:down-arrow {
  image: url('$STYLED_ICONS_PATH/sort-asc.svg');
  max-width: 16px;
  min-width: 16px;
  max-height: 16px;
  min-height: 16px;
}

QHeaderView:up-arrow {
  image: url('$STYLED_ICONS_PATH/sort-desc.svg');
  max-width: 16px;
  min-width: 16px;
  max-height: 16px;
  min-height: 16px;
}

QHeaderView:section {
  /* Header of tables */
  border: 1px solid $primary-background-color-alt-2;
  background-color: $primary-background-color-alt-2;
  padding: 6px;
  spacing: 10px;
}

QHeaderView:section:hover, QHeaderView:section:focus {
  background-color: $primary-background-color-alt-3;
  border: 0 solid $primary-text-color;
}

QTableView {
  outline: none;
  alternate-background-color: $primary-background-color-alt-2;
  background-color: $primary-background-color;
  color: $primary-text-color;
}
QTableView:item{
  color: $primary-text-color;
}

QProgressBar {
  border: 0 solid $primary-background-color-alt-4;
  border-radius: 4px;
  background-color: $primary-background-color-alt-2;
  padding: 1px;
  max-width: 240px;
  max-height: 20px;
  min-height: 20px;
}

QProgressBar:chunk {
  background-color: $progressbar-color;
  width: 10px;
  margin: 0;
}

QLabel[icon="info"]{
  qproperty-pixmap: url("$IMAGE_PATH/icons/info-active.svg")
}

QLabel[icon="warn"]{
  qproperty-pixmap: url("$IMAGE_PATH/icons/warning-active.svg")
}


LineEditSearch {
  border-radius: 12px;
}

FrameBody {
  /* This is the main body container (Side bar plus content) */
  background: $primary-background-color;
}

FrameTabBody {
  /* This is the container for the content of the tabs */
  border: 1px solid $primary-background-color-alt-4;
  margin: 16px;
}

FrameTabHeader {
  border-bottom: 1px solid $primary-background-color-alt-4;
  padding: 12px;
  max-height: 26px;
  min-height: 26px;
  /* Needed to guarantee a size on OSX and linux */
}

FrameTabHeader QLabel {
  font-size: 16px;
}

FrameTabFooter {
  border: 1px solid transparent;
  border-top: 1px solid $primary-background-color-alt-4;
  min-height: 20px;
  padding: 6px;
}

FrameDialog {
  /* Frame container for TitleBar and Body */
  border: 1px solid $primary-background-color-alt-4;
  margin: 10px;
}

FrameDialogTitleBar {
  background: $secondary-background-color;
  border-bottom: 1px solid $primary-background-color-alt-4;
  padding: 0 0 0 12px;
  max-height: 32px;
  min-height: 32px;
}

FrameDialogTitleBar QWidget {
  color: $secondary-text-color;
}

FrameDialogTitleBar ButtonDialogClose {
  qproperty-icon: url("$IMAGE_PATH/icons/dialog-close.svg");
  qproperty-iconSize: 14px 14px;
}

FrameDialogBody {
  background: $primary-background-color;
  padding: 16px;
}

FrameDialogBody ButtonNormal,
FrameDialogBody ButtonPrimary,
FrameDialogBody ButtonDanger {
  border-width: 2px;
  border-radius: 15px;
  padding: 2px 24px;
  min-width: 60px;
  max-width: 120px;
}

SpacerVertical, SpacerHorizontal {
  /* Uses a QLabel to allow tweaking spacing between buttons in forms etc.   */
  max-height: 12px;
  min-height: 12px;
}


ButtonBase,
ButtonToolBase {
  color: $primary-text-color;
  border: 1px solid transparent;
  border-bottom: 2px solid transparent;
  padding: 0 10px;
  margin: 0;
  outline: none; /* Remove the focus rect in ubuntu and macos */
}

ButtonBase:focus {
  text-decoration: underline;
}

ButtonToggleCollapse {
  border: 1px solid transparent;
  border-bottom: 2px solid $primary-background-color-alt-4;
  background: $primary-background-color-alt-2;
  color: $primary-text-color;
  qproperty-iconSize: 14px;
}

ButtonToggleCollapse:hover,
ButtonToggleCollapse:focus {
  background: $primary-background-color-alt-3;
}

ButtonToggleCollapse {
  border: 1px solid $primary-background-color-alt-4;
  border-top-width: 0;
  border-bottom-width: 0;
  max-width: 24px;
  min-width: 24px;
  qproperty-iconSize: 24px;
}

ButtonToggleCollapse[checked="false"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/arrow-left.svg");
}

ButtonToggleCollapse[checked="true"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/arrow-right.svg");
}

IconButton {
  background-position: center;
  background-repeat: no-repeat;
  qproperty-icon: url(" ");
  /*
   * To use this style:
   * - set `background-image` to a valid icon url
   * - set `qproperty-iconSize` to a desired size of the icon
   */
}

ButtonHomeRefresh {
  background-image: url("$IMAGE_PATH/icons/refresh.svg");
  qproperty-iconSize: 24px;
}

ButtonHomeRefresh:focus,
ButtonHomeRefresh:hover {
  background-image: url("$IMAGE_PATH/icons/refresh-hovered.svg");
}

ButtonHomeRefresh:pressed {
  background-image: url("$IMAGE_PATH/icons/refresh-pressed.svg");
}

ButtonNormal {
  background: $primary-background-color-alt-2;
  border-color: transparent;
  border-radius: 13px;
  border-style: solid;
  border-width: 1px;
  color: $primary-text-color-alt-1;
  font-weight: 700;
  margin: 0;
  max-height: 24px;
  min-height: 24px;
  outline: none;
  padding: 0 16px;
}

ButtonNormal:focus {
  text-decoration: underline;
}

ButtonNormal:disabled {
  background: $primary-background-color-alt-5;
  color: $primary-text-color-alt-2;
}

ButtonNormal:focus,
ButtonNormal:hover {
  background: $primary-background-color-alt-4;
}

ButtonNormal:pressed {
  background: $primary-background-color-alt-5;
}

ButtonCancel {
  background: $primary-background-color-alt-2;
  border-color: transparent;
  border-radius: 13px;
  border-style: solid;
  border-width: 1px;
  color: $primary-text-color-alt-1;
  font-weight: 700;
  margin: 0;
  max-height: 24px;
  min-height: 24px;
  outline: none;
  padding: 0 16px;
}

ButtonCancel:focus {
  text-decoration: underline;
}

ButtonCancel:disabled {
  background: $primary-background-color-alt-5;
  color: $primary-text-color-alt-2;
}

ButtonCancel:hover {
  background: $primary-background-color-alt-4;
}

ButtonCancel:pressed {
  background: $primary-background-color-alt-5;
}

ButtonPrimary {
  background: #D9EFDB;
  border-color: transparent;
  border-radius: 13px;
  border-style: solid;
  border-width: 1px;
  color: $primary-selection-color-alt-1;
  font-weight: 700;
  margin: 0;
  max-height: 24px;
  min-height: 24px;
  outline: none;
  padding: 0 16px;
}

ButtonPrimary:focus {
  text-decoration: underline;
}

ButtonPrimary:disabled {
  background: $primary-background-color-alt-5;
  color: $primary-text-color-alt-2;
}

ButtonPrimary:hover {
  background: $primary-selection-color-alt-3;
}

ButtonPrimary:pressed {
  background: $primary-selection-color-alt-4;
}

ButtonDanger {
  background: #F1CAD1;
  border-color: transparent;
  border-radius: 13px;
  border-style: solid;
  border-width: 1px;
  color: #7A0920;
  font-weight: 700;
  margin: 0;
  max-height: 24px;
  min-height: 24px;
  outline: none;
  padding: 0 16px;
}

ButtonDanger:focus {
  text-decoration: underline;
}

ButtonDanger:disabled {
  background: $primary-background-color-alt-5;
  color: $primary-text-color-alt-2;
}

ButtonDanger:hover {
  background: #E7A8B4;
}

ButtonDanger:pressed {
  background: #DD8697;
}

FrameTabHeader ButtonNormal {
  background-color: $primary-background-color-alt-2;
  border-color: $primary-background-color-alt-4;
  color: $primary-text-color;
  font-weight: 500;
}

FrameTabHeader ButtonNormal:hover {
  background-color: $primary-background-color-alt-3;
}

FrameTabHeader ButtonNormal:pressed {
  background-color:$primary-background-color-alt-4;
}

ButtonLink {
  background: none;
  border: none;
  color: $primary-selection-color;
  padding: 1px;
  text-align: left;
}

ButtonLink:focus {
  text-decoration: underline;
}

ButtonLink:hover, ButtonLink:focus {
  color: $primary-selection-color-alt-1;
}

ButtonLabel:disabled {
  color: $primary-text-color;
}

ButtonLogin{
  background-color: $primary-selection-color-alt-1;
  border-color: $primary-background-color;
  border-radius: 20px;
  border-style: outset;
  border-width: 2px;
  color: $secondary-text-color;
  font-size: 12px;
  font-weight: 700;
  padding: 6px 24px 6px 18px;
  qproperty-icon: url("$IMAGE_PATH/icons/account-expand.svg");
  qproperty-iconSize: 20px;
}

ButtonLogin:focus {
  text-decoration: none;
}

ButtonLogin:focus,
ButtonLogin:hover {
  background: $primary-selection-color-alt-2;
}

ButtonLabelLogin {
  font: 16px/24px Museo Sans Rounded;
}

FrameHeader {
  /* This is the top (anaconda logo, login buttons) container */
  background: $primary-background-color;
  min-height: 48px;
  padding: 4px 25px;
  border-bottom: 1px solid $primary-background-color-alt-4;
}

FrameHeader LabelBeta {
  padding: 12px 5px 0 5px;
  font: 100 normal 10px "Ubuntu";
  color: $secondary-text-color;
  max-height: 1em;
  min-height: 1em;
}

FrameHeader ButtonLabel:disabled {
  color: $primary-text-color;
}

FrameHeader ButtonHeaderUpdate {
  border: 1px dashed transparent;
  color: $primary-selection-color;
  font: 400 normal 14px "Ubuntu";
  padding: 4px;
  qproperty-iconSize: 24px;
  qproperty-icon: url("$IMAGE_PATH/icons/info-green.svg");
}

FrameHeader ButtonHeaderUpdate[hovered="true"],
FrameHeader ButtonHeaderUpdate[focused="true"],
FrameHeader ButtonHeaderUpdate[pressed="true"]{
  qproperty-icon: url("$IMAGE_PATH/icons/info-green-active.svg");
  color: $primary-selection-color-alt-1;
}

FrameHeader ButtonHeaderUpdate[focused="true"] {
  border: 1px dashed $primary-background-color-alt-5;
  color: $primary-selection-color-alt-1;
}

FrameTabBar {
  /* This is the side navigation bar container */
  background: $primary-background-color-alt-2;
  border-right: 1px solid $primary-background-color-alt-4;
  margin: 0;
  max-width: 200px;
  min-width: 200px;
}

FrameTabBar FrameTabBarBottom {
  padding: 20px;
  padding-bottom: 42px;
}

FrameTabBar FrameTabBarBottom FrameTabBarLink {
  padding: 20px 0;
}

FrameTabBar FrameTabBarBottom FrameTabBarLink ButtonLink {
  text-align: center;
  color: $primary-text-color;
  padding: 8px 12px;
  margin: 6px 0;
  background: $primary-background-color;
}

FrameTabBar FrameTabBarBottom FrameTabBarLink ButtonLink:hover {
  color: $primary-selection-color;
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial {
  padding: 0;
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink {
  background: transparent;
  border: 1px dashed transparent;
  font: 100 normal 1px "Ubuntu";
  padding: 4px;
  padding-left: 6px;
  padding-right: 0;
  margin: 0;
  qproperty-iconSize: 24px;
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink:focus,
FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink:hover {
  border: 1px dashed $primary-background-color-alt-7;
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#twitter {
  qproperty-icon: url("$STYLED_ICONS_PATH/twitter.svg");
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#twitter[hovered="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/twitter-active.svg");
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#github {
  qproperty-icon: url("$STYLED_ICONS_PATH/github.svg");
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#github[hovered="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/github-active.svg");
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#youtube {
  qproperty-icon: url("$STYLED_ICONS_PATH/youtube.svg");
}

FrameTabBar FrameTabBarBottom FrameTabBarSocial ButtonLink#youtube[hovered="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/youtube-active.svg");
}

ButtonTab {
  background: $primary-background-color-alt-2;
  border-bottom: 1px solid $primary-background-color-alt-4;
  font: 300 normal 14px "Ubuntu";
  min-height: 32px;
  max-height: 64px;
  padding: 10px 24px;
  qproperty-iconSize: 24px;
  /* Specific icons per button */
}

ButtonTab[checked="true"] {
  background: $primary-background-color-alt-1;
  color: $primary-selection-color;
}

ButtonTab[checked="false"]:focus, ButtonTab[checked="false"]:hover {
  background: $primary-background-color-alt-1;
}

ButtonTab:focus {
  text-decoration: underline;
}

ButtonTab#home[checked="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/home-active.svg");
}

ButtonTab#home[checked="false"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/home.svg");
}

ButtonTab#environments[checked="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/env-active.svg");
}

ButtonTab#environments[checked="false"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/env.svg");
}

ButtonTab#community[checked="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/community-active.svg");
}

ButtonTab#community[checked="false"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/community.svg");
}

ButtonTab#learning[checked="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/learning-active.svg");
}

ButtonTab#learning[checked="false"] {
  qproperty-icon: url("$STYLED_ICONS_PATH/learning.svg");
}

LabelTabHeader {
  margin: 0;
  color: $primary-text-color-alt-1;
  padding: 6px;
}

ButtonSearch {
  margin-right: 6px;
  image: url("$STYLED_ICONS_PATH/close.svg");
  max-width: 20px;
  min-width: 20px;
}

ButtonSearch:disabled {
  image: url("$STYLED_ICONS_PATH/search.svg");
}

ButtonSearch[focused="true"] {
  image: url("$IMAGE_PATH/icons/close-active.svg");
}

ButtonShow {
  margin-right: 6px;
  image: url("$STYLED_ICONS_PATH/eye.svg");
  max-width: 20px;
  min-width: 20px;
}

ButtonShow:disabled {
  image: url("$IMAGE_PATH/icons/eye-disabled.svg");
}

ButtonShow[focused="true"] {
  image: url("$IMAGE_PATH/icons/eye-active.svg");
}

ListWidgetApplication {
  background-color: $primary-background-color-alt-2;
  padding: 5px;
  outline: none;
}

WidgetApplication {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-5;
  padding: 5;
  margin: 5;
  max-width: 240;
  min-width: 240;
}

LabelApplicationIcon {
  margin: 0;
  padding: 0;
  max-height: 64;
  min-height: 64;
}

LabelApplicationName {
  padding: 5px;
  font: 100 normal 14px "Ubuntu";
  max-height: 1em;
  min-height: 1em;
}

FrameApplicationSpinner {
  padding: 0;
  margin: 0;
  max-width: 16px;
  min-width: 16px;
  max-height: 16px;
  min-height: 16px;
}

LabelApplicationLicense, ButtonApplicationLicense {
  padding-left: 1px;
  padding-right: 1px;
  margin: 0;
  max-height: 20px;
  min-height: 20px;
  font: 600 normal 11px "Ubuntu";
}

ButtonApplicationVersion {
  max-height: 1em;
  min-height: 1em;
  font: 300 normal 11px "Ubuntu";
  padding: 0;
  margin: 0;
  qproperty-icon: none;
  qproperty-iconSize: 16px;
}

ButtonApplicationVersion[pressed="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/update-app-active.svg");
  color: $progressbar-color;
}

LabelApplicationDescription {
  font: 100 normal 12px "Ubuntu";
  max-height: 6.2em;
  min-height: 6.2em;
  padding: 0;
}

ButtonApplicationInstall {
  background: $primary-background-color;
  border: 1px solid $primary-selection-color;
  color: $primary-selection-color;
  padding: 4 10px;
  margin: 5px;
}

ButtonApplicationInstall[focused="false"], ButtonApplicationInstall[hovered="false"] {
  background-color: $primary-background-color;
}

ButtonApplicationInstall[focused="true"], ButtonApplicationInstall[hovered="true"] {
  color: $secondary-text-color;
  background-color: $primary-selection-color;
}

ButtonApplicationInstall[disabled="true"] {
  background-color: $primary-background-color;
  color: $primary-text-color-alt-2;
}

ButtonApplicationInstall:disabled {
  border: 1px solid $primary-background-color-alt-6;
}

ButtonApplicationLaunch {
  background: $primary-background-color;
  border: 1px solid $progressbar-color;
  color: $progressbar-color;
  padding: 4 10px;
  margin: 5px;
}

ButtonApplicationLaunch[focused="false"], ButtonApplicationLaunch[hovered="false"] {
  background-color: $primary-background-color;
}

ButtonApplicationLaunch[focused="true"], ButtonApplicationLaunch[hovered="true"] {
  color: $secondary-text-color;
  background-color: $progressbar-color;
}

ButtonApplicationLaunch[disabled="true"] {
  background-color: $primary-background-color-alt-3;
  color: $primary-text-color-alt-2;
}

ButtonApplicationLaunch:disabled {
  border: 1px solid $primary-background-color-alt-6;
}

ButtonApplicationOptions {
  max-width: 16px;
  min-width: 16px;
  max-height: 16px;
  min-height: 16px;
  background: none;
  border: 1px solid transparent;
  image: url("$STYLED_ICONS_PATH/settings.svg");
  padding: 5px;
}

ButtonApplicationOptions:hover, ButtonApplicationOptions:focus {
  background: $primary-background-color;
  border: 1px dashed $primary-background-color-alt-7;
}

ButtonApplicationOptions:disabled {
  border: 1px solid $primary-background-color;
  background: none;
  image: url("$IMAGE_PATH/icons/settings-disabled.svg");
}

FrameEnvironmentsList {
  max-width: 280px;
  min-width: 280px;
  background: $primary-background-color;
}

ListWidgetEnv {
  background-color: $primary-background-color-alt-2;
  outline: 0;
}

EnvListDialog BaseListWidgetEnv ButtonEnvironmentName {
  font-size: 16px;
}

EnvListDialog BaseListWidgetEnv {
  border: 1px solid $primary-background-color-alt-5;
  background-color: $primary-background-color-alt-1;
}

WidgetEnvironment {
  background: $primary-background-color-alt-1;
  border-bottom: 1px solid $primary-background-color-alt-5;
  border-left: 4px solid transparent;
  outline: none;
  padding-left: 5px;
  padding-right: 5px;
}

WidgetEnvironment[hovered="true"],
WidgetEnvironment[focused="true"] {
  border-left: 4px solid $primary-selection-color;
}

WidgetEnvironment[pressed="true"] {
  border-left: 4px solid $primary-selection-color-alt-1;
  color: $primary-selection-color-alt-1;
}

WidgetEnvironment ButtonEnvironmentName {
  color: $primary-text-color;
  max-width: 160px;
  min-width: 160px;
  padding-bottom: 4px;
  text-align: left;
}

WidgetEnvironment ButtonEnvironmentName[pressed="true"] {
  color: $primary-selection-color-alt-1;
}

WidgetEnvironment ButtonEnvironmentName[hovered="true"] {
  color: $primary-selection-color;
}

WidgetEnvironment ButtonEnvironmentName:focus {
  color: $primary-selection-color-alt-1;
}

WidgetEnvironment FrameEnvironmentIcon {
  max-width: 20px;
  min-width: 20px;
  padding: 4px;
}

WidgetEnvironment ButtonEnvironmentOptions {
  border: 1px dashed transparent;
  padding: 5px;
  qproperty-icon: url("$IMAGE_PATH/icons/env-options-active.svg");
  qproperty-iconSize: 24px;
}

WidgetEnvironment ButtonEnvironmentOptions:hover,
WidgetEnvironment ButtonEnvironmentOptions:focus {
  border: 1px dashed $primary-selection-color-alt-1;
}

ButtonToolNormal {
  background: $primary-background-color-alt-2;
  border: 1px solid transparent;
  border-top-color: $primary-background-color-alt-4;
  color: $primary-text-color;
  max-height: 48px;
  min-height: 48px;
  min-width: 42px;
  padding: 0;
  qproperty-iconSize: 24px;
}

ButtonToolNormal:hover,
ButtonToolNormal:focus {
  background: $primary-background-color-alt-3;
}

ButtonToolNormal#create {
  qproperty-icon: url("$STYLED_ICONS_PATH/env-add.svg");
}

ButtonToolNormal#create[hovered="true"][enabled="true"],
ButtonToolNormal#create[focused="true"][enabled="true"] {
  color: $primary-selection-color;
  qproperty-icon: url("$IMAGE_PATH/icons/env-add-active.svg");
}

ButtonToolNormal#clone {
  qproperty-icon: url("$STYLED_ICONS_PATH/env-clone.svg");
}

ButtonToolNormal#clone[hovered="true"][enabled="true"],
ButtonToolNormal#clone[focused="true"][enabled="true"] {
  color: $primary-selection-color;
  qproperty-icon: url("$IMAGE_PATH/icons/env-clone-active.svg");
}

ButtonToolNormal#import {
  qproperty-icon: url("$STYLED_ICONS_PATH/env-import.svg");
}

ButtonToolNormal#import[hovered="true"][enabled="true"],
ButtonToolNormal#import[focused="true"][enabled="true"] {
  color: $primary-selection-color;
  qproperty-icon: url("$IMAGE_PATH/icons/env-import-active.svg");
}

ButtonToolNormal#backup {
  qproperty-icon: url("$STYLED_ICONS_PATH/env-backup.svg");
}

ButtonToolNormal#backup[hovered="true"][enabled="true"],
ButtonToolNormal#backup[focused="true"][enabled="true"] {
  color: $primary-selection-color;
  qproperty-icon: url("$IMAGE_PATH/icons/env-backup-active.svg");
}

ButtonToolNormal#remove {
  border-right: 1px solid transparent;
  qproperty-icon: url("$STYLED_ICONS_PATH/delete.svg");
}

ButtonToolNormal#remove[hovered="true"][enabled="true"],
ButtonToolNormal#remove[focused="true"][enabled="true"] {
  color: #BA0C2F;
  qproperty-icon: url("$IMAGE_PATH/icons/delete-active.svg");
}

LabelBase#environment-location {
  font-style: italic;
  font-size: 10px;
  color: $primary-text-color-alt-1;
}

ButtonNormal#import {
  qproperty-icon: url("$STYLED_ICONS_PATH/open.svg");
  qproperty-iconSize: 24px;
}

ButtonNormal#import[focused="true"] {
  qproperty-icon: url("$IMAGE_PATH/icons/open-active.svg");
}


ButtonToggle {
  margin: 0;
  outline: none;
  /* Remove the focus rectangle in Ubuntu and OSX */
  padding: 0 10px;
  max-height: 24px;
  min-height: 24px;
  border: 1px solid $primary-text-color-alt-2;
}

ButtonToggle:focus {
  text-decoration: underline;
}

ButtonToggle:disabled {
  background: $primary-background-color-alt-5;
}

ButtonToggle#documentation[checked="true"] {
  background: $primary-selection-color-alt-1;
  color: $secondary-text-color;
}

ButtonToggle#documentation[checked="true"]:hover, ButtonToggle#documentation[checked="true"]:focus {
  background: $primary-selection-color;
}

ButtonToggle#training[checked="true"] {
  background: #615E9B;
  color: $secondary-text-color;
}

ButtonToggle#training[checked="true"]:hover, ButtonToggle#training[checked="true"]:focus {
  background: #7e7cb0;
}

ButtonToggle#video[checked="true"] {
  background: #006298;
  color: $secondary-text-color;
}

ButtonToggle#video[checked="true"]:hover, ButtonToggle#video[checked="true"]:focus {
  background: #0084cb;
}

ButtonToggle#webinar[checked="true"] {
  background: #F3D03E;
  color: $secondary-text-color;
}

ButtonToggle#webinar[checked="true"]:hover, ButtonToggle#webinar[checked="true"]:focus {
  background: #f6db6e;
}

ButtonToggle#event[checked="true"] {
  background: #006298;
  color: $secondary-text-color;
}

ButtonToggle#event[checked="true"]:hover, ButtonToggle#event[checked="true"]:focus {
  background: #0084cb;
}

ButtonToggle#forum[checked="true"] {
  background: #615E9B;
  color: $secondary-text-color;
}

ButtonToggle#forum[checked="true"]:hover, ButtonToggle#forum[checked="true"]:focus {
  background: #7e7cb0;
}

ButtonToggle#social[checked="true"] {
  background: $primary-selection-color-alt-1;
  color: $secondary-text-color;
}

ButtonToggle#social[checked="true"]:hover, ButtonToggle#social[checked="true"]:focus {
  background: $primary-selection-color;
}

ButtonToggle[checked="false"] {
  background: $primary-background-color;
  color: $primary-text-color;
}

ButtonToggle[checked="false"]:hover, ButtonToggle[checked="false"]:focus {
  background: $primary-background-color-alt-3;
}

ListWidgetContent {
  background: $primary-background-color-alt-2;
  outline: none;
  padding: 0;
}

FrameContent {
  background: $primary-background-color;
  margin: 5px;
  padding: 0;
  padding-bottom: 0;
  max-width: 190px;
  min-width: 190px;
}

ButtonContentText {
  color: $secondary-text-color;
  font-size: 13px;
  margin: 0;
  padding: 0;
  max-height: 2em;
  min-height: 2em;
  max-width: 190px;
  min-width: 190px;
}

ButtonContentText#documentation {
  background: $primary-selection-color-alt-1;
}

ButtonContentText#documentation:focus, ButtonContentText#documentation:hover {
  background: #003d23;
}

ButtonContentText#documentation[active="true"] {
  background: #003d23;
}

ButtonContentText#training {
  background: #615E9B;
}

ButtonContentText#training:focus, ButtonContentText#training:hover {
  background: #4c4b7b;
}

ButtonContentText#training[active="true"] {
  background: #4c4b7b;
}

ButtonContentText#video {
  background: #006298;
}

ButtonContentText#video:focus, ButtonContentText#video:hover {
  background: #004265;
}

ButtonContentText#video[active="true"] {
  background: #004265;
}

ButtonContentText#webinar {
  background: #F3D03E;
  background: #F3D03E;
}

ButtonContentText#webinar:focus, ButtonContentText#webinar:hover {
  background: #efc20f;
}

ButtonContentText#webinar[active="true"] {
  background: #efc20f;
}

ButtonContentText#event {
  background: #006298;
}

ButtonContentText#event:focus, ButtonContentText#event:hover {
  background: #004265;
}

ButtonContentText#event[active="true"] {
  background: #004265;
}

ButtonContentText#forum {
  background: #615E9B;
}

ButtonContentText#forum:focus, ButtonContentText#forum:hover {
  background: #4c4b7b;
}

ButtonContentText#forum[active="true"] {
  background: #4c4b7b;
}

ButtonContentText#social {
  background: $primary-selection-color-alt-1;
}

ButtonContentText#social:focus, ButtonContentText#social:hover {
  background: #003d23;
}

ButtonContentText#social[active="true"] {
  background: #003d23;
}

FrameTabHeader#documentation, FrameContentHeader#documentation {
  background: $primary-selection-color-alt-1;
}

FrameTabHeader#training, FrameContentHeader#training {
  background: #615E9B;
}

FrameTabHeader#video, FrameContentHeader#video {
  background: #006298;
}

FrameTabHeader#webinar, FrameContentHeader#webinar {
  background: #F3D03E;
}

FrameTabHeader#event, FrameContentHeader#event {
  background: #006298;
}

FrameTabHeader#forum, FrameContentHeader#forum {
  background: #615E9B;
}

FrameTabHeader#social, FrameContentHeader#social {
  background: $primary-selection-color-alt-1;
}

FrameContentHeader {
  max-height: 7px;
  min-height: 7px;
  border: 1 solid $primary-background-color-alt-5;
  border-bottom: 1px solid transparent;
}

FrameContentBody {
  padding: 0;
  margin: 0;
  border: 1 solid $primary-background-color-alt-5;
}

LabelContentIcon {
  border: 0 solid $primary-background-color-alt-5;
}


LabelContentIcon[icon="default"]{
  qproperty-pixmap: url("$IMAGE_PATH/default-content.png");
}


FrameContentIcon {
  border-bottom: 1 solid $primary-background-color-alt-5;
  max-height: 105;
  min-height: 105;
  max-width: 188;
  min-width: 188;
}

LabelContentTitle {
  padding: 2px;
  margin: 0;
  max-height: 45px;
}

LabelContentTitle[active="true"] {
  color: $primary-selection-color;
}

ButtonContentInformation, LabelEmpty {
  min-height: 16x;
  padding-bottom: 2px;
  font-size: 11px;
}

ListWidgetChannels {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-5;
  outline: none;
  padding: 0;
}

FrameChannels {
  background: $primary-background-color-alt-2;
  border-bottom: 1px solid $primary-background-color-alt-4;
  margin: 0;
  padding: 10px;
  max-height: 50px;
  min-height: 50px;
}

FrameChannels QLineEdit {
  border: 1px solid transparent;
  max-width: 250px;
  min-width: 250px;
}

FrameChannels QLineEdit:read-only {
  background: $primary-background-color-alt-2;
}

FrameChannels QLineEdit:disabled {
  background: $primary-background-color-alt-2;
  color: $primary-text-color;
}

FrameChannels LabelConfigLocation {
  padding: 6px;
  max-width: 300;
  min-width: 300;
  max-height: 20px;
  min-height: 20px;
  font-style: italic;
  font-size: 10px;
  color: $primary-text-color-alt-1;
}

FrameChannels LabelChannelInfo {
  padding: 6px;
  max-width: 24px;
  min-width: 24px;
  image: url("$IMAGE_PATH/icons/warning-active.svg");
}

FrameChannels LabelChannelInfo:disabled {
  image: none;
}

FrameChannels ButtonDanger {
  background: transparent;
  padding: 5px;
  qproperty-icon: url("$STYLED_ICONS_PATH/delete.svg");
  qproperty-iconSize: 24px;
}

FrameChannels ButtonDanger[focused="true"], FrameChannels ButtonDanger:focus {
  background: transparent;
  border: 1px dashed #BA0C2F;
  qproperty-icon: url("$IMAGE_PATH/icons/delete-active.svg");
}

FrameChannels ButtonDanger:hover, FrameChannels ButtonDanger[hovered="true"] {
  background: transparent;
  qproperty-icon: url("$IMAGE_PATH/icons/delete-active.svg");
}

ListWidgetLog {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-5;
  outline: none;
  padding: 5px;
  max-width: 660;
  min-width: 660;
}

ListWidgetLog:item {
  padding: 5px;
  border: 1px solid transparent;
}

ListWidgetLog:item:selected {
  color: $primary-selection-color;
  border: 1px solid $primary-selection-color;
}

ListWidgetActionPackages {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-5;
  outline: none;
  padding: 0;
  max-width: 280;
  min-width: 280;
}

ListWidgetActionPackages:item {
  background: $primary-background-color-alt-2;
  border-bottom: 1px solid $primary-background-color-alt-4;
  padding: 5px;
}

ListWidgetActionPackages:item:selected {
  background: $primary-selection-color;
  color: $secondary-text-color;
}

ListRunningApps {
  background: $primary-background-color;
  border: 1px solid $primary-background-color-alt-5;
  outline: none;
  padding: 0;
  max-width: 280;
  min-width: 280;
}

FrameRunningApps {
  background: $primary-background-color-alt-2;
  border-bottom: 1px solid $primary-background-color-alt-4;
  margin: 0;
  padding: 10;
  max-height: 19;
  min-height: 19;
}

FrameRunningApps QLabel {
  padding: 0;
  margin: 0;
}
ButtonDialogClose{
  qproperty-icon: url("$STYLED_ICONS_PATH/close.svg");
}

StaticFrameDialog {
  border: 1px solid $primary-background-color-alt-4;
  background: $primary-background-color;
  border-radius: 8px;
  margin: 0;
  padding: 0;
}

StaticFrameDialogTitleBar {
  background: $primary-background-color;
  border-radius: 8px;
  padding: 8px 0 0 0;
  max-height: 32px;
  min-height: 32px;
}

StaticFrameDialogBody {
  background: $primary-background-color;
  border-radius: 8px;
  padding: 0 15px 0 56px;
}

LabelMainLoginTitle {
  max-width: 640px;
  white-space: pre-line;
  font: 48px/58px "Ubuntu";
  color: $primary-text-color;
  margin-bottom: 15px;
}

LabelMainLoginText {
  max-width: 640px;
  white-space: pre-line;
  font: normal 16px/24px "Ubuntu";
  color: $primary-text-color-alt-1;
  margin-bottom: 5px;
}

LabelMainLoginSubTitle {
  max-width: 640px;
  font: 14px/32px "Ubuntu";
  color: $primary-text-color-alt-2;
  text-transform: uppercase;
  padding-left: 3px;
}

WidgetLoginInfoFrame {
  min-width: 300px;
  max-width: 300px;
  padding-right: 25px;
  max-height: 230px;
  margin-bottom: 110px;
}

WidgetLoginInfoFrame LabelLoginLogo {
  margin: 7px 0;
  max-height: 67px;
}

WidgetLoginInfoFrame QLabel {
  white-space: pre-line;
  font: normal 16px/24px "Ubuntu";
  color: $primary-text-color-alt-1;
  margin-bottom: 5px;
}

WidgetLoginFormFrame {
  min-width: 300px;
  max-width: 300px;
  max-height: 210px;
  margin-bottom: 40px;
  padding-right: 50px;
}

WidgetLoginFormFrame LabelMainLoginText {
  font: normal normal normal 16px/24px Museo Sans Rounded;
  color: $primary-text-color-alt-1;
}

WidgetLoginFormFrame LabelMainLoginSubTitle {
  font: italic normal normal 12px/16px Museo Sans Rounded;
  color: $primary-text-color-alt-1;
  text-transform: none;
}

WidgetLoginFormFrame QLabel {
  min-width: 15px;
  font: normal 14px/16px "Ubuntu";
  color: $primary-text-color-alt-2;
  margin: 5px 0 0 0;
  padding: 0;
}

WidgetLoginFormFrame ButtonLabel {
  font: lighter 12px/14px "Ubuntu";
  color: $primary-text-color-alt-2;
}

WidgetLoginFormFrame ButtonLink {
  font: lighter 2px/14px "Ubuntu";
  color: $primary-selection-color;
}

WidgetLoginFormFrame QLineEdit {
  min-height: 30px;
  border: 0.5px solid #707070;
  border-radius: 4px;
  font: normal normal normal 16px/24px "Ubuntu";
  color: $primary-text-color-alt-1;
  margin: 0 0 7px 0;
}

WidgetLoginFormFrame ButtonPrimary {
  background-color: $primary-selection-color-alt-2;
  border-style: outset;
  border-width: 2px;
  border-radius: 20px;
  color: #FFFFFF;
  padding: 6px;
  margin: 10px;
  min-width: 75px;
  max-width: 75px;
}

WidgetLoginFormFrame ButtonPrimary:focus,
WidgetLoginFormFrame ButtonPrimary:hover {
  background: $primary-selection-color-alt-1;
}

WidgetLoginFormFrame ButtonPrimary:pressed {
  background: $primary-selection-color;
}

WidgetNoticeFrame {
  margin-bottom: 20px;
  margin-right: 40px;
}

WidgetNoticeFrame QLabel {
  color: $primary-text-color-alt-1;
  font: normal 24px/32px "Ubuntu";
  margin-bottom: 55px;
  white-space: pre-line;
}

WidgetNoticeFrame ButtonCancel,
WidgetNoticeFrame ButtonPrimary {
  border-style: outset;
  border-radius: 20px;
  border-width: 2px;
  margin-bottom: 10px;
  max-width: 100px;
  min-width: 100px;
  padding: 6px;
}


BasePage {
  min-width: 760px;
  max-width: 760px;
  min-height: 500px;
  max-height: 500px;
  border: 1px solid $secondary-background-color;
}

BasePage LabelMainLoginTitle {
  max-height: 120px;
}

NoticePage {
  max-height: 400px;
  max-width: 760px;
  min-height: 400px;
  min-width: 760px;
}

TrustServerDialog {
  max-height: 400px;
  max-width: 760px;
  min-height: 400px;
  min-width: 760px;
}

TrustServerDialog ButtonPrimary {
  width: 180px;
  text-decoration: none;
}

TrustServerDialog ButtonCancel {
  width: 100px;
}

TrustServerDialog LabelMainLoginTitle {
  font: 38px/48px "Ubuntu";
}

EnterpriseRepoSetDomainPage WidgetLoginFormFrame,
TeamEditionSetDomainPage WidgetLoginFormFrame,
CommercialEditionLoginPage WidgetLoginFormFrame,
CommercialEditionLoginPage WidgetLoginInfoFrame {
  min-width: 300px;
  max-width: 300px;
  max-height: 280px;
  margin-bottom: 50px;
  padding-right: 50px;
}

TeamEditionAddChannelsPage ButtonPrimary {
  background-color: $primary-selection-color-alt-2;
  border-style: outset;
  border-width: 2px;
  border-radius: 20px;
  color: #FFFFFF;
  padding: 6px;
  margin: 20px 35px 20px 20px;
  min-width: 100px;
  max-width: 100px;
}

TeamEditionAddChannelsPage ButtonPrimary:hover, TeamEditionAddChannelsPage ButtonPrimary:pressed {
  background: $primary-selection-color-alt-1;
}

TeamEditionAddChannelsPage QLabel {
  min-width: 15px;
  font: normal 14px/16px "Ubuntu";
  color: $primary-text-color-alt-2;
  margin: 5px 0 0 0;
  padding: 0;
}

TeamEditionAddChannelsPage LabelLoginLogo {
  margin-bottom: 10px;
}

TeamEditionAddChannelsPage QLabel {
  margin-bottom: 20px;
}

SelectableChannelsListTable {
  gridline-color: $primary-text-color;
}

SelectableChannelsListTable::item {
  background-color: $primary-background-color;
  color: $primary-text-color;
}

SecondaryButton {
  text-align: left;
  font: 16px/24px "Ubuntu";
  color: #0075A9;
  background: none;
  text-transform: uppercase;
  margin: 0 7px 7px 2px;
}
SecondaryButton:focus, SecondaryButton:hover, SecondaryButton:pressed{
  color: #00a9a9;
  background: none;
}

ListWidgetProblems {
  background: $primary-background-color-alt-2;
  border: 1px solid $primary-background-color-alt-5;
  outline: none;
  padding: 0;
}

ListWidgetProblems:item {
  background: $primary-background-color-alt-2;
  border-bottom: 1px solid $primary-background-color-alt-5;
  padding: 5px;
  max-width: 280px;
  min-width: 280px;
}

ListWidgetProblems:item:selected {
  background: $primary-background-color;
  color: $primary-text-color;
}

LabelImageLinkVertical QLabel {
  background-color: $primary-background-color;
  color: $primary-text-color;
}

AccountsFrame {
  background-color: $primary-background-color;
  border-color: $primary-text-color-alt-1;
  border-radius: 6px;
  border-style: solid;
  border-width: 1px;
  margin: 0;
  max-width: 300px;
  min-width: 300px;
  padding: 4px 0;
}

AccountsFrame AccountsTitle {
  border-bottom-color: $primary-background-color-alt-4;
  border-bottom-style: solid;
  border-bottom-width: 1px;
}

AccountsFrame AccountsTitle QLabel {
  color: $primary-text-color;
  font-size: 18px;
  font-weight: 500;
  margin: 8px 10px 18px;
}

AccountsFrame AccountsHeader {
  border-bottom-color: $primary-background-color-alt-4;
  border-bottom-style: solid;
  border-bottom-width: 1px;
}

AccountsFrame AccountsHeader QLabel {
  color: $primary-text-color-alt-1;
  font-size: 11px;
  font-weight: 700;
  margin: 20px 10px 4px;
}

AccountsFrame AccountEntry {
  background-color: $primary-background-color-alt-1;
  border-bottom-color: $primary-background-color-alt-4;
  border-bottom-style: solid;
  border-bottom-width: 1px;
}

AccountsFrame AccountEntry AccountEntryPrefix {
  color: $primary-background-color-alt-7;
  font-size: 10px;
  font-weight: 500;
  margin: 4px 10px 0;
}

AccountsFrame AccountEntry AccountEntryPrefix:disabled {
  color: $primary-background-color-alt-5;
}

AccountsFrame AccountEntry AccountEntryTitle {
  color: $primary-selection-color;
  font-size: 16px;
  font-weight: 500;
  margin: 1px 10px;
}

AccountsFrame AccountEntry AccountEntryTitle:disabled {
  color: $primary-background-color-alt-7;
}

AccountsFrame AccountEntry AccountEntryAction {
  color: $primary-text-color-alt-1;
  font-size: 12px;
  font-weight: 700;
  margin: 1px 10px;
}

AccountsFrame AccountEntry AccountEntryAction:disabled {
  color: $primary-background-color-alt-5;
}

AccountsFrame AccountEntry AccountEntryPostfix {
  color: $primary-background-color-alt-7;
  font-size: 10px;
  font-weight: 500;
  margin: 0 10px 4px;
}

AccountsFrame AccountEntry AccountEntryPostfix:disabled {
  color: $primary-background-color-alt-5;
}

AccountsLabel[icon="error"]{
  qproperty-pixmap: url("$IMAGE_PATH/icons/exclamation-circle.svg");
}

OpenIconButton {
  background-image: url("$STYLED_ICONS_PATH/open.svg");
  qproperty-iconSize: 24px;
}

EnvSelectorDialog BaseListWidgetEnv {
  border: 1px solid $primary-background-color-alt-5;
}

WarningIcon {
  qproperty-pixmap: url("$IMAGE_PATH/icons/exclamation.svg");
}

WarningLabel LabelBase {
  margin-top: 4px;
  color: $warning-color;
}

WarningBlock {
  background-color: #FFEBC0;
  border-radius: 8px;
  padding: 16px 26px;
}

ErrorIcon {
  qproperty-pixmap: url("$IMAGE_PATH/icons/exclamation-circle.svg");
  width: 20px;
  height: 20px;
}

ErrorLabel LabelBase {
  margin-left: 5px;
  font: 400 normal 14px "Ubuntu";
  color: $warning-color;
}

ErrorBlock {
  background-color: #FAE7DC;
  border-radius: 8px;
  padding: 16px 26px;
}

InfoIcon {
  qproperty-pixmap: url("$IMAGE_PATH/icons/check-circle.svg");
  width: 20px;
  height: 20px;
}

InfoLabel LabelBase {
  margin-left: 5px;
  font: 400 normal 14px "Ubuntu";
  color: $primary-selection-color-alt-2;
}

InfoBlock {
  background-color: #ECF5D9;
  border-radius: 8px;
  padding: 16px 26px;
}

TeamEditionServerAlert {
  margin: 0;
  padding: 0;
}

TeamEditionServerAlert InfoBlock,
TeamEditionServerAlert ErrorBlock {
  border-radius: 0;
  margin: 0;
  padding: 14px 22px;
}

TeamEditionServerAlert InfoIcon {
  qproperty-pixmap: url("$IMAGE_PATH/icons/team-edition-online.svg");
}

TeamEditionServerAlert ErrorIcon {
  qproperty-pixmap: url("$IMAGE_PATH/icons/team-edition-offline.svg");
}

DotControlButton {
  background-color: $primary-selection-color;
  border: none;
  border-radius: 5px;
  width: 11px;
  height: 11px;
}

DotControlButton:pressed,
DotControlButton:checked {
  background-color: #6C5AF6;
}

SurveyDialog ButtonDialogClose {
  qproperty-icon: url('$STYLED_ICONS_PATH/close.svg');
  qproperty-iconSize: 24px 24px;
}

SurveyDialog {
  background: $primary-background-color;
}

SurveyDialog FrameBase{
  max-height: 24px;
  min-height: 24px;
}

PasswordVisibleIcon{
  qproperty-icon: url("$STYLED_ICONS_PATH/eye-visible.svg");
}

PasswordHiddenIcon {
  qproperty-icon: url("$IMAGE_PATH/icons/eye-hidden.svg");
}

AnacondaSvgLogo {
  qproperty-svgPath: url("$IMAGE_PATH/anaconda-logo.svg");
}

AnacondaNavigatorSvgLogo{
  qproperty-svgPath: url("$STYLED_IMAGE_PATH/anaconda-navigator-logo.svg");
}

AnacondaLoginPage LabelLoginLogo{
  qproperty-pixmap: url("$STYLED_IMAGE_PATH/logos/Anaconda_Logo_RGB_Org.png")
}

CommercialEditionLoginPage LabelLoginLogo{
  qproperty-pixmap: url("$STYLED_IMAGE_PATH/logos/Logo-Professional.png")
}

EnterpriseRepoSetDomainPage LabelLoginLogo,
EnterpriseRepoLoginPage LabelLoginLogo{
  qproperty-pixmap: url("$STYLED_IMAGE_PATH/logos/Logo-Enterprise.png")
}

TeamEditionSetDomainPage LabelLoginLogo,
TeamEditionLoginPage LabelLoginLogo,
TeamEditionAddChannelsPage LabelLoginLogo{
  qproperty-pixmap: url("$STYLED_IMAGE_PATH/logos/Logo-Server.png")
}

TeamEditionAddChannelsPage LabelLoginLogo{
  max-width: 200px;
  max-height: 45px;
  qproperty-scaledContents: 1;
}

BaseCleanDialog CleanDialogFrame{
  background: $primary-background-color;
  border: 2px solid $primary-background-color-alt-3;
  border-radius: 8px;
}
BaseCleanDialog *{
  margin: 0;
  padding: 0;
  font: 400 normal 16px Inter;
  text-align: left;
  font-size: 16px;
  font-weight: 400;
  line-height: 24px;
  color: $primary-text-color-alt-1;
}

BaseCleanDialog CleanDialogHeaderFrame{
  padding: 0 10px;
}

BaseCleanDialog CleanDialogBodyFrame{
  padding: 0 24px 24px 24px;
}


BaseCleanDialog ButtonPrimary{
  text-align: center;
  font-weight: 700;
  border-radius: 4px;

  color: #000000;
  background: #0CCA4A;
  min-width: 100px;
  min-height: 40px;
  border: 1px;
}
BaseCleanDialog ButtonSecondaryTextual{
  text-align: center;
  text-decoration: none;
  font-weight: 700;
  border-radius: 4px;

  background: none;
  border: 1px solid #6D5BF6;
  color: #6D5BF6;
  min-width: 235px;
  min-height: 40px;
}

BaseCleanDialog ButtonLink{
  color: #6C5AF6;
  text-decoration: underline;
  min-height: 24px;
  font-size: 16px;
  min-width: 100px;
  min-height: 40px;
}

ButtonSecondaryTextual:focus,
ButtonSecondaryTextual:hover,
ButtonSecondaryTextual:pressed{
  background: none;
  border: 1px solid #9689ff;
  color: #9689ff;
}

BaseCleanDialog ButtonLink:focus,
BaseCleanDialog ButtonLink:hover,
BaseCleanDialog ButtonLink:pressed{
    color: #9689ff;
}

BaseCleanDialog ButtonDialogClose{
  qproperty-iconSize: 18px 18px;
  max-height: 18px;
  margin: 12px 12px 0 0;
  padding: 0;
}

BaseCleanDialog QComboBox::drop-down {
  border-left-width: 0;
  padding-right: 10px;
}

BaseCleanDialog QComboBox:on::drop-down {
  /* Height can be changed here */
  /*border-radius: 0;*/
  min-height: 40px;
  padding-left: 24px;
  margin-bottom: 0;
}


BaseCleanDialog CleanDialogTitle{
  font: 700 normal 24px Inter;
  line-height: 36px;
  padding: 0;
  margin: 0 0 8px 0;
}

RepoSelectorDialog{
  min-width: 500px;
  min-height: 316px;
}

SeparatorLine{
  background: $primary-background-color-alt-1;
}

LoginReminderDialog QLabel#LoginReminderImage{
  qproperty-pixmap: url("$IMAGE_PATH/content/cloud_ai_ad.png");
  max-width: 452px;
  max-height: 346px;
  border: 1px solid $primary-background-color-alt-1;
}

LoginReminderDialog{
  min-width: 520px;
  min-height: 598px;
}

